@@ -1,25 +1,15 @@
-library(testthat)
-library(RSocrata)
-library(httr)
-library(jsonlite)
-library(mime)
-library(plyr)
-
-## Credentials for testing private dataset and update dataset functionality ##
-# This is commented out because of issue #174 as a temporary work-around. 
-# This should be re-enabled in the future with a work-around.
-socrataEmail <- Sys.getenv("SOCRATA_EMAIL", "mark.silverberg+soda.demo@socrata.com")
-socrataPassword <- Sys.getenv("SOCRATA_PASSWORD", "7vFDsGFDUG")
 
 context("posixify function")
 
 test_that("read Socrata CSV is compatible with posixify", {
+  skip_on_cran()
   df <- read.socrata('https://soda.demo.socrata.com/resource/4334-bgaj.csv')
   dt <- posixify("09/14/2012 10:38:01 PM")
   expect_equal(dt, df$datetime[1])  ## Check that download matches test
 })
 
 test_that("read Socrata JSON is compatible with posixify (issue 85)", {
+  skip_on_cran()
   ## Define and test issue 85
   df <- read.socrata('https://soda.demo.socrata.com/resource/9szf-fbd4.json')
   dt <- posixify("09/14/2012 10:38:01 PM")
@@ -27,6 +17,7 @@ test_that("read Socrata JSON is compatible with posixify (issue 85)", {
 })
 
 test_that("read Socrata JSON that uses ISO 8601 but does not specify subseconds", {
+  skip_on_cran()
   df <- read.socrata('https://data.cityofnewyork.us/resource/qcdj-rwhu.json') # Not from #121, but smaller for shorter test process
   expect_false(anyNA(df$app_status_date), info= "Testing issue 121 https://github.com/Chicago/RSocrata/issues/121")
 })
@@ -57,6 +48,7 @@ test_that("posixify returns Short format", {
 context("Socrata Calendar")
 
 test_that("Calendar Date Short", {
+  skip_on_cran()
   df <- read.socrata('https://data.cityofchicago.org/resource/y93d-d9e3.csv?$order=debarment_date')
   dt <- df$debarment_date[1] # "05/21/1981"
   expect_equal("POSIXct", class(dt)[1], label="data type of a date")
@@ -70,6 +62,8 @@ test_that("Calendar Date Short", {
 
 test_that("Date is not entirely NA if the first record is bad (issue 68)", {
   
+  skip_on_cran()
+  
   ## Define and test issue 68
   # df <- read.socrata('https://data.cityofchicago.org/resource/me59-5fac.csv')
   # expect_false(object = all(is.na(df$Creation.Date)),
@@ -101,6 +95,9 @@ test_that("Fields with currency symbols remove the symbol and convert to money",
 })
 
 test_that("converts money fields to numeric from Socrata", {
+  
+  skip_on_cran()
+  
   df <- read.socrata("https://data.cityofchicago.org/Administration-Finance/Current-Employee-Names-Salaries-and-Position-Title/xzkq-xp2w")
   expect_equal("numeric", class(df$annual_salary), label="dollars")
   expect_equal("numeric", class(df$annual_salary), label="output of money fields")
@@ -109,6 +106,9 @@ test_that("converts money fields to numeric from Socrata", {
 context("read Socrata")
 
 test_that("read Socrata CSV as default", {
+  
+  skip_on_cran()
+  
   df <- read.socrata('https://soda.demo.socrata.com/resource/4334-bgaj.csv')
   expect_equal("data.frame", class(df), label="class")
   expect_equal(1007, nrow(df), label="rows")
@@ -120,6 +120,9 @@ test_that("read Socrata CSV as default", {
 })
 
 test_that("read Socrata CSV from New Backend (NBE) endpoint", {
+  
+  skip_on_cran()
+  
   df <- read.socrata("https://odn.data.socrata.com/resource/pvug-y23y.csv")
   expect_equal("data.frame", class(df), label="class", info="https://github.com/Chicago/RSocrata/issues/118")
   expect_equal(4, ncol(df), label="columns", info="https://github.com/Chicago/RSocrata/issues/118")
@@ -130,6 +133,8 @@ test_that("read Socrata CSV from New Backend (NBE) endpoint", {
 
 test_that("Warn instead of fail if X-SODA2-* headers are missing", {
   
+  skip_on_cran()
+  
   ## Note: The examples with missing Soda2 headers are missing and need to be replaced
   ## or the issue should be fixed with Socrata / Tyler.
   ## See issue 196
@@ -166,6 +171,9 @@ test_that("Warn instead of fail if X-SODA2-* headers are missing", {
 })
 
 test_that("read Socrata CSV as character", {
+  
+  skip_on_cran()
+  
   df <- read.socrata('https://soda.demo.socrata.com/resource/4334-bgaj.csv',
                      stringsAsFactors = FALSE)
   expect_equal("data.frame", class(df), label="class")
@@ -177,6 +185,9 @@ test_that("read Socrata CSV as character", {
 })
 
 test_that("read Socrata CSV as factor", {
+  
+  skip_on_cran()
+  
   df <- read.socrata('https://soda.demo.socrata.com/resource/4334-bgaj.csv',
                      stringsAsFactors = TRUE)
   expect_equal("data.frame", class(df), label="class")
@@ -189,6 +200,9 @@ test_that("read Socrata CSV as factor", {
 
 
 test_that("read Socrata JSON as default", {
+  
+  skip_on_cran()
+  
   df <- read.socrata('https://soda.demo.socrata.com/resource/4334-bgaj.json')
   expect_equal("data.frame", class(df), label="class")
   expect_equal(1007, nrow(df), label="rows")
@@ -200,6 +214,9 @@ test_that("read Socrata JSON as default", {
 })
 
 test_that("read Socrata JSON as character", {
+  
+  skip_on_cran()
+  
   df <- read.socrata('https://soda.demo.socrata.com/resource/4334-bgaj.json',
                      stringsAsFactors = FALSE)
   expect_equal("data.frame", class(df), label="class")
@@ -212,6 +229,9 @@ test_that("read Socrata JSON as character", {
 })
 
 test_that("read Socrata JSON as factor", {
+  
+  skip_on_cran()
+  
   df <- read.socrata('https://soda.demo.socrata.com/resource/4334-bgaj.json',
                      stringsAsFactors = TRUE)
   expect_equal("data.frame", class(df), label="class")
@@ -224,32 +244,44 @@ test_that("read Socrata JSON as factor", {
 
 
 test_that("read Socrata No Scheme", {
+
+  skip_on_cran()
+  
   expect_error(read.socrata('soda.demo.socrata.com/resource/4334-bgaj.csv'))
 })
 
 test_that("readSoQL", {
+  
+  skip_on_cran()
+  
   df <- read.socrata('https://soda.demo.socrata.com/resource/4334-bgaj.csv?$select=region')
   expect_equal(1007, nrow(df), label="rows")
   expect_equal(1, ncol(df), label="columns")
 })
 
-test_that("URL is private (Unauthorized) (will fail)", {
-  expect_error(read.socrata('https://data.cityofchicago.org/resource/j8vp-2qpg.json'))
-})
 
 test_that("readSocrataHumanReadable", {
+  
+  skip_on_cran()
+  
   df <- read.socrata('https://soda.demo.socrata.com/dataset/USGS-Earthquake-Reports/4334-bgaj')
   expect_equal(1007, nrow(df), label="rows")
   expect_equal(9, ncol(df), label="columns")
 })
 
 test_that("Read URL provided by data.json from ls.socrata() - CSV", {
+  
+  skip_on_cran()
+  
   df <- read.socrata('https://soda.demo.socrata.com/api/views/4334-bgaj/rows.csv?accessType=DOWNLOAD')
   expect_equal(1007, nrow(df), label="rows", info="Testing for issue #124")
   expect_equal(9, ncol(df), label="columns")
 })
 
 test_that("Read URL provided by data.json from ls.socrata() - JSON", {
+  
+  skip_on_cran()
+  
   df <- read.socrata('https://soda.demo.socrata.com/api/views/4334-bgaj/rows.json?accessType=DOWNLOAD')
   expect_equal(1007, nrow(df), label="rows", info="Testing for issue #124")
   expect_equal(9, ncol(df), label="columns")
@@ -267,11 +299,17 @@ test_that("Read URL provided by data.json from ls.socrata() - JSON", {
 # })
 
 test_that("format is not supported", {
+  
+  skip_on_cran()
+  
   # Unsupported data formats
   expect_error(read.socrata('https://soda.demo.socrata.com/resource/4334-bgaj.xml'))
 })
 
 test_that("read Socrata JSON with missing fields (issue 19 - bind within page)", {
+  
+  skip_on_cran()
+  
   ## Define and test issue 19
   expect_error(df <- read.socrata("https://data.cityofchicago.org/resource/kn9c-c2s2.json"), NA,
                info = "https://github.com/Chicago/RSocrata/issues/19")
@@ -290,6 +328,9 @@ test_that("read Socrata JSON with missing fields (issue 19 - binding pages toget
 })
 
 test_that("Accept a URL with a $limit= clause and properly limit the results", {
+  
+  skip_on_cran()
+  
   ## Define and test issue 83
   df <- read.socrata("https://soda.demo.socrata.com/resource/4334-bgaj.json?$LIMIT=500") # uppercase
   expect_equal(500, nrow(df), label="rows", 
@@ -306,6 +347,9 @@ test_that("Accept a URL with a $limit= clause and properly limit the results", {
 })
   
 test_that("If URL has no queries, insert $order:id into URL", {
+  
+  skip_on_cran()
+  
   ## Define and test issue 15
   ## Ensure that the $order=:id is inserted when no other query parameters are used.
   df <- read.socrata("https://data.cityofchicago.org/resource/kn9c-c2s2.json")
@@ -321,6 +365,9 @@ test_that("If URL has no queries, insert $order:id into URL", {
 })
 
 test_that("If URL has an $order clause, do not insert ?$order:id into URL", {
+  
+  skip_on_cran()
+  
   ## Define and test issue 15
   ## Ensure that $order=:id is not used when other $order parameters are requested by the user.
   df <- read.socrata("https://data.cityofchicago.org/resource/kn9c-c2s2.json?$order=hardship_index")
@@ -335,6 +382,9 @@ test_that("If URL has an $order clause, do not insert ?$order:id into URL", {
 })
 
 test_that("If URL has only non-order query parameters, insert $order:id into URL", {
+  
+  skip_on_cran()
+  
   ## Define and test issue 15
   ## Ensure that $order=:id is inserted when other (non-$order) arguments are used.
   df <- read.socrata("https://data.cityofchicago.org/resource/kn9c-c2s2.json?$limit=50")
@@ -358,6 +408,9 @@ test_that("If URL has only non-order query parameters, insert $order:id into URL
 })
 
 test_that("Handle URL with query that does not return :id", {
+  
+  skip_on_cran()
+  
   ## Define and test issue 120
   ## Ensure that the $order=:id is inserted when no other query parameters are used.
   qurl <-  "https://data.cityofchicago.org/resource/wrvz-psew.csv?$select=count(trip_id)&$where=trip_start_timestamp between '2016-04-01T00:00:00' and '2016-04-05T00:00:00'"
@@ -379,6 +432,9 @@ test_that("is 4x4", {
 
 
 test_that("is 4x4 URL", {
+  
+  skip_on_cran()
+  
   expect_error(read.socrata("https://soda.demo.socrata.com/api/views/4334c-bgajc"), "4334c-bgajc is not a valid Socrata dataset unique identifier", label="11 characters instead of 9")
   expect_error(read.socrata("https://soda.demo.socrata.com/api/views/433-bga"), "433-bga is not a valid Socrata dataset unique identifier", label="7 characters instead of 9")
   expect_error(read.socrata("https://soda.demo.socrata.com/api/views/433-bgaj"), "433-bgaj is not a valid Socrata dataset unique identifier", label="3 characters before dash instead of 4")
@@ -386,12 +442,19 @@ test_that("is 4x4 URL", {
 })
 
 test_that("Invalid URL", {
+  
+  ## This one could probably run on CRAN, but being cautious
+  skip_on_cran()
+  
   expect_error(read.socrata("a.fake.url.being.tested"), "a.fake.url.being.tested does not appear to be a valid URL", label="invalid url")
 })
 
 context("Test Socrata with Token")
 
 test_that("CSV with Token", {
+  
+  skip_on_cran()
+  
   df <- read.socrata('https://soda.demo.socrata.com/resource/4334-bgaj.csv', app_token="ew2rEMuESuzWPqMkyPfOSGJgE")
   expect_equal(1007, nrow(df), label="rows")
   expect_equal(9, ncol(df), label="columns")  
@@ -399,12 +462,18 @@ test_that("CSV with Token", {
 
 
 test_that("readSocrataHumanReadableToken", {
+  
+  skip_on_cran()
+  
   df <- read.socrata('https://soda.demo.socrata.com/dataset/USGS-Earthquake-Reports/4334-bgaj', app_token="ew2rEMuESuzWPqMkyPfOSGJgE")
   expect_equal(1007, nrow(df), label="rows")
   expect_equal(9, ncol(df), label="columns")  
 })
 
 test_that("API Conflict", {
+  
+  skip_on_cran()
+  
   df <- read.socrata('https://soda.demo.socrata.com/resource/4334-bgaj.csv?$$app_token=ew2rEMuESuzWPqMkyPfOSGJgE', app_token="ew2rEMuESuzWPqMkyPfOSUSER")
   expect_equal(1007, nrow(df), label="rows")
   expect_equal(9, ncol(df), label="columns")
@@ -413,6 +482,9 @@ test_that("API Conflict", {
 })
 
 test_that("readAPIConflictHumanReadable", {
+  
+  skip_on_cran()
+  
   df <- read.socrata('https://soda.demo.socrata.com/dataset/USGS-Earthquake-Reports/4334-bgaj?$$app_token=ew2rEMuESuzWPqMkyPfOSGJgE', app_token="ew2rEMuESuzWPqMkyPfOSUSER")
   expect_equal(1007, nrow(df), label="rows")
   expect_equal(9, ncol(df), label="columns")
@@ -421,6 +493,9 @@ test_that("readAPIConflictHumanReadable", {
 })
 
 test_that("incorrect API Query", {
+  
+  skip_on_cran()
+  
   # The query below is missing a $ before app_token.
   expect_error(read.socrata("https://soda.demo.socrata.com/resource/4334-bgaj.csv?$app_token=ew2rEMuESuzWPqMkyPfOSGJgE"))
   # Check that it was only because of missing $  
@@ -430,12 +505,18 @@ test_that("incorrect API Query", {
 })
 
 test_that("Ensure filtering and app tokens can coexist - API", {
+  
+  skip_on_cran()
+  
   # Test includes filter and app_token as an R optional argument
   df <- read.socrata("https://soda.demo.socrata.com/resource/4334-bgaj.csv?$where=magnitude > 3.0", app_token="ew2rEMuESuzWPqMkyPfOSGJgE")
   expect_equal(193, nrow(df), label = "rows", info = "https://github.com/Chicago/RSocrata/issues/105")
 })
 
 test_that("incorrect API Query Human Readable", {
+  
+  skip_on_cran()
+  
   # The query below is missing a $ before app_token.
   expect_error(read.socrata("https://soda.demo.socrata.com/dataset/USGS-Earthquake-Reports/4334-bgaj?$app_token=ew2rEMuESuzWPqMkyPfOSGJgE"))
   # Check that it was only because of missing $  
@@ -447,6 +528,9 @@ test_that("incorrect API Query Human Readable", {
 context("URL suffixes from Socrata are handled")
 
 test_that("Handle /data suffix", {
+  
+  skip_on_cran()
+  
   df1 <- read.socrata('https://soda.demo.socrata.com/dataset/USGS-Earthquake-Reports/4334-bgaj/data')
   expect_equal(1007, nrow(df1), label="rows")
   expect_equal(9, ncol(df1), label="columns")
@@ -458,6 +542,9 @@ test_that("Handle /data suffix", {
 context("ls.socrata functions correctly")
 
 test_that("List datasets available from a Socrata domain", {
+  
+  skip_on_cran()
+  
   # Makes some potentially erroneous assumptions about availability
   # of soda.demo.socrata.com
   df <- ls.socrata("https://soda.demo.socrata.com")
@@ -473,75 +560,14 @@ test_that("List datasets available from a Socrata domain", {
 })
 
 test_that("Catalog Fields are assigned as attributes when listing data sets", {
+  
+  skip_on_cran()
+  
   df <- ls.socrata("https://soda.demo.socrata.com")
   catalog_fields <- c("@context", "@id", "@type", "conformsTo", "describedBy")
   expect_equal(as.logical(rep(TRUE, length(catalog_fields))), catalog_fields %in% names(attributes(df)))
 })
 
-context("Test reading private Socrata dataset with email and password")
-
-privateResourceToReadCsvUrl <- "https://soda.demo.socrata.com/resource/a9g2-feh2.csv"
-privateResourceToReadJsonUrl <- "https://soda.demo.socrata.com/resource/a9g2-feh2.json"
-
-test_that("read Socrata CSV that requires a login", {
-  skip('See Issue #174')
-  # should error when no email and password are sent with the request
-  expect_error(read.socrata(url = privateResourceToReadCsvUrl))
-  # try again, this time with email and password in the request
-  df <- read.socrata(url = privateResourceToReadCsvUrl, email = socrataEmail, password = socrataPassword)
-  # tests
-  expect_equal(2, ncol(df), label="columns")
-  expect_equal(3, nrow(df), label="rows")
-})
-
-test_that("read Socrata JSON that requires a login", {
-  skip('See Issue #174')
-  # should error when no email and password are sent with the request
-  expect_error(read.socrata(url = privateResourceToReadJsonUrl))
-  # try again, this time with email and password in the request
-  df <- read.socrata(url = privateResourceToReadJsonUrl, email = socrataEmail, password = socrataPassword)
-  # tests
-  expect_equal(2, ncol(df), label="columns")
-  expect_equal(3, nrow(df), label="rows")
-})
-
-context("write Socrata datasets")
-
-test_that("add a row to a dataset", {
-  skip('See Issue #174')
-  datasetToAddToUrl <- "https://soda.demo.socrata.com/resource/xh6g-yugi.json"
-
-  # populate df_in with two columns, each with a random number
-  x <- sample(-1000:1000, 1)
-  y <- sample(-1000:1000, 1)
-  df_in <- data.frame(x,y)
-
-  # write to dataset
-  res <- write.socrata(df_in,datasetToAddToUrl,"UPSERT",socrataEmail,socrataPassword)
-  
-  # Check that the dataset was written without error
-  expect_equal(res$status_code, 200L)
-
-})
-
-
-test_that("fully replace a dataset", {
-  skip('See Issue #174')
-  datasetToReplaceUrl <- "https://soda.demo.socrata.com/resource/kc76-ybeq.json"
-
-  # populate df_in with two columns of random numbers
-  x <- sample(-1000:1000, 5)
-  y <- sample(-1000:1000, 5)
-  df_in <- data.frame(x,y)
-
-  # write to dataset
-  res <- write.socrata(df_in,datasetToReplaceUrl,"REPLACE",socrataEmail,socrataPassword)
-
-  # Check that the dataset was written without error
-  expect_equal(res$status_code, 200L)
-})
-
-
 context("getContentAsDataFrame")
 
 test_that("getContentAsDataFrame does not get caught in infinite loop", {
